@@ -2,7 +2,7 @@
 
 from enum import Enum
 from math import sqrt
-from typing import Iterator, List, NamedTuple, Tuple, Union
+from typing import Any, Iterator, List, NamedTuple, Tuple, Union
 
 from mcipc.rcon.enumerations import Item
 
@@ -25,7 +25,7 @@ class Anchor(Enum):
     TOP_RIGHT = 'top_right'
     BOTTOM_LEFT = 'bottom_left'
     BOTTOM_RIGHT = 'bottom_right'
-    MIDDLE = 'middle'
+    CENTER = CENTRE = MIDDLE = 'middle'
 
 
 class Vec3(NamedTuple):
@@ -35,15 +35,20 @@ class Vec3(NamedTuple):
     y: Union[int, float] = 0
     z: Union[int, float] = 0
 
-    def __add__(self, other):
+    def __add__(self, other: Vec3):
         return type(self)(self.x + other.x, self.y + other.y, self.z + other.z)
 
-    def __sub__(self, other):
+    def __sub__(self, other: Vec3):
         return type(self)(self.x - other.x, self.y - other.y, self.z - other.z)
 
-    def __mul__(self, other):
+    def __mul__(self, other: Union[int, float]):
         return type(self)(self.x * other, self.y * other, self.z * other)
 
+    @property
+    def is_direction(self):
+        """Determines whether this is a direction vector."""
+        return sum(coord != 0 for coord in self) == 1
+
     @property
     def dx(self):   # pylint: disable=C0103
         """Returns the absolute x value."""
@@ -51,12 +56,12 @@ class Vec3(NamedTuple):
 
     @property
     def dy(self):   # pylint: disable=C0103
-        """Returns the absolute x value."""
+        """Returns the absolute y value."""
         return abs(self.y)
 
     @property
     def dz(self):   # pylint: disable=C0103
-        """Returns the absolute x value."""
+        """Returns the absolute z value."""
         return abs(self.z)
 
     @property
@@ -105,6 +110,10 @@ class Direction(Enum):
     SOUTH = Vec3(0, 0, +1)
     NORTH = Vec3(0, 0, -1)
 
+    def __getattr__(self, attr: str) -> Any:
+        """Delegates to the value."""
+        return getattr(self.value, attr)
+
 
 Row = List[Union[Item, None]]
 Profile = List[Row]
